# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .agent import Agent
from .agent_summary import AgentSummary
from .group_summary import GroupSummary
from .schedule_summary import ScheduleSummary


class Actor_Agent(Agent):
    type: typing.Literal["agent"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class Actor_AgentSummary(AgentSummary):
    type: typing.Literal["agent_summary"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class Actor_GroupSummary(GroupSummary):
    type: typing.Literal["group_summary"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class Actor_ScheduleSummary(ScheduleSummary):
    type: typing.Literal["schedule_summary"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


Actor = typing.Union[Actor_Agent, Actor_AgentSummary, Actor_GroupSummary, Actor_ScheduleSummary]
