# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Options(str, enum.Enum):
    DISABLED = "disabled"
    EXPIRED = "expired"
    FORGOTTEN = "forgotten"
    INVITED = "invited"
    LOCKED = "locked"

    def visit(
        self,
        disabled: typing.Callable[[], T_Result],
        expired: typing.Callable[[], T_Result],
        forgotten: typing.Callable[[], T_Result],
        invited: typing.Callable[[], T_Result],
        locked: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is Options.DISABLED:
            return disabled()
        if self is Options.EXPIRED:
            return expired()
        if self is Options.FORGOTTEN:
            return forgotten()
        if self is Options.INVITED:
            return invited()
        if self is Options.LOCKED:
            return locked()
