# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class TimeseriesOptions(str, enum.Enum):
    HOUR = "hour"

    def visit(self, hour: typing.Callable[[], T_Result]) -> T_Result:
        if self is TimeseriesOptions.HOUR:
            return hour()
