# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.scheduledjobactivity.resources.classes.types.scheduled_job_activity import (
    ScheduledJobActivity as resources_ocsf_resources_v_1_3_0_resources_scheduledjobactivity_resources_classes_types_scheduled_job_activity_ScheduledJobActivity,
)

ScheduledJobActivity = resources_ocsf_resources_v_1_3_0_resources_scheduledjobactivity_resources_classes_types_scheduled_job_activity_ScheduledJobActivity
