# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.dnsactivity.resources.classes.types.dns_activity import (
    DnsActivity as resources_ocsf_resources_v_1_3_0_resources_dnsactivity_resources_classes_types_dns_activity_DnsActivity,
)

DnsActivity = resources_ocsf_resources_v_1_3_0_resources_dnsactivity_resources_classes_types_dns_activity_DnsActivity
