# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.vulnerabilityfinding.resources.classes.types.vulnerability_finding import (
    VulnerabilityFinding as resources_ocsf_resources_v_1_3_0_resources_vulnerabilityfinding_resources_classes_types_vulnerability_finding_VulnerabilityFinding,
)

VulnerabilityFinding = resources_ocsf_resources_v_1_3_0_resources_vulnerabilityfinding_resources_classes_types_vulnerability_finding_VulnerabilityFinding
