# This file was auto-generated by Fern from our API Definition.

from ...ocsf.resources.v_1_3_0.resources.configstate.resources.classes.types.config_state import ConfigState

PostureScore = ConfigState
