# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class BridgeSelector_Id(pydantic.BaseModel):
    type: typing.Literal["id"]
    value: str

    class Config:
        frozen = True
        smart_union = True


class BridgeSelector_Labels(pydantic.BaseModel):
    type: typing.Literal["labels"]
    value: typing.List[str]

    class Config:
        frozen = True
        smart_union = True


BridgeSelector = typing.Union[BridgeSelector_Id, BridgeSelector_Labels]
