# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.networkactivity.resources.classes.types.network_activity import (
    NetworkActivity as resources_ocsf_resources_v_1_3_0_resources_networkactivity_resources_classes_types_network_activity_NetworkActivity,
)

NetworkActivity = (
    resources_ocsf_resources_v_1_3_0_resources_networkactivity_resources_classes_types_network_activity_NetworkActivity
)
