# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.fileactivity.resources.classes.types.file_activity import (
    FileActivity as resources_ocsf_resources_v_1_3_0_resources_fileactivity_resources_classes_types_file_activity_FileActivity,
)

FileActivity = (
    resources_ocsf_resources_v_1_3_0_resources_fileactivity_resources_classes_types_file_activity_FileActivity
)
