# This file was auto-generated by Fern from our API Definition.

from ...ocsf.resources.v_1_3_0.resources.detectionfinding.resources.classes.types.detection_finding import (
    DetectionFinding,
)

ThreatEvent = DetectionFinding
