# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ReadWriteActions(str, enum.Enum):
    READ = "read"
    READ_WRITE = "*"

    def visit(self, read: typing.Callable[[], T_Result], read_write: typing.Callable[[], T_Result]) -> T_Result:
        if self is ReadWriteActions.READ:
            return read()
        if self is ReadWriteActions.READ_WRITE:
            return read_write()
