# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.entitymanagement.resources.classes.types.entity_management import (
    EntityManagement as resources_ocsf_resources_v_1_3_0_resources_entitymanagement_resources_classes_types_entity_management_EntityManagement,
)

EntityManagement = resources_ocsf_resources_v_1_3_0_resources_entitymanagement_resources_classes_types_entity_management_EntityManagement
