# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Environment(str, enum.Enum):
    TEST = "test"
    PROD = "prod"

    def visit(self, test: typing.Callable[[], T_Result], prod: typing.Callable[[], T_Result]) -> T_Result:
        if self is Environment.TEST:
            return test()
        if self is Environment.PROD:
            return prod()
