# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.securityfinding.resources.classes.types.security_finding import (
    SecurityFinding as resources_ocsf_resources_v_1_3_0_resources_securityfinding_resources_classes_types_security_finding_SecurityFinding,
)

SecurityFinding = (
    resources_ocsf_resources_v_1_3_0_resources_securityfinding_resources_classes_types_security_finding_SecurityFinding
)
