# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.moduleactivity.resources.classes.types.module_activity import (
    ModuleActivity as resources_ocsf_resources_v_1_3_0_resources_moduleactivity_resources_classes_types_module_activity_ModuleActivity,
)

ModuleActivity = (
    resources_ocsf_resources_v_1_3_0_resources_moduleactivity_resources_classes_types_module_activity_ModuleActivity
)
