# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ProviderEnvironment(str, enum.Enum):
    PRODUCTION = "prod"
    """
    Provider may be used with production accounts.
    """

    TEST = "test"
    """
    Provider may be used with test accounts.
    """

    def visit(self, production: typing.Callable[[], T_Result], test: typing.Callable[[], T_Result]) -> T_Result:
        if self is ProviderEnvironment.PRODUCTION:
            return production()
        if self is ProviderEnvironment.TEST:
            return test()
