# This file was auto-generated by Fern from our API Definition.

from .armis_credential import ArmisCredential, ArmisCredential_Token, ArmisCredential_TokenId
from .assets_armis_centrix import AssetsArmisCentrix
from .assets_armis_centrix_mock import AssetsArmisCentrixMock
from .assets_armis_dataset import AssetsArmisDataset
from .assets_axonius import AssetsAxonius
from .assets_crowd_strike import AssetsCrowdStrike
from .assets_nozomi_vantage import AssetsNozomiVantage
from .assets_nozomi_vantage_dataset import AssetsNozomiVantageDataset
from .assets_nozomi_vantage_mock import AssetsNozomiVantageMock
from .assets_qualys_cloud import AssetsQualysCloud
from .assets_qualys_cloud_dataset import AssetsQualysCloudDataset
from .assets_qualys_cloud_mock import AssetsQualysCloudMock
from .assets_service_now import AssetsServiceNow
from .assets_service_now_dataset import AssetsServiceNowDataset
from .assets_service_now_mock import AssetsServiceNowMock
from .assets_sevco import AssetsSevco
from .assets_tanium_cloud import AssetsTaniumCloud
from .assets_tanium_cloud_dataset import AssetsTaniumCloudDataset
from .assets_tanium_cloud_mock import AssetsTaniumCloudMock
from .autotask_api_integration_code_credential import (
    AutotaskApiIntegrationCodeCredential,
    AutotaskApiIntegrationCodeCredential_Secret,
    AutotaskApiIntegrationCodeCredential_SecretId,
)
from .autotask_secret_credential import (
    AutotaskSecretCredential,
    AutotaskSecretCredential_Secret,
    AutotaskSecretCredential_SecretId,
)
from .aws_s_3_credential import AwsS3Credential, AwsS3Credential_Aws, AwsS3Credential_AwsId
from .aws_security_lake_credential import (
    AwsSecurityLakeCredential,
    AwsSecurityLakeCredential_Aws,
    AwsSecurityLakeCredential_AwsId,
)
from .aws_sqs_credential import AwsSqsCredential, AwsSqsCredential_Aws, AwsSqsCredential_AwsId
from .axonius_credential import AxoniusCredential, AxoniusCredential_Basic, AxoniusCredential_BasicId
from .azure_blob_credential import AzureBlobCredential, AzureBlobCredential_Token, AzureBlobCredential_TokenId
from .azure_monitor_logs_credential import (
    AzureMonitorLogsCredential,
    AzureMonitorLogsCredential_Token,
    AzureMonitorLogsCredential_TokenId,
)
from .cloud_security_crowd_strike import CloudSecurityCrowdStrike
from .cloud_security_defender import CloudSecurityDefender
from .crowd_strike_credential import (
    CrowdStrikeCredential,
    CrowdStrikeCredential_OAuthClient,
    CrowdStrikeCredential_OAuthClientId,
)
from .crowdstrike_hec_credential import (
    CrowdstrikeHecCredential,
    CrowdstrikeHecCredential_Token,
    CrowdstrikeHecCredential_TokenId,
)
from .custom_field_mapping import CustomFieldMapping
from .defender_credential import DefenderCredential, DefenderCredential_OAuthClient, DefenderCredential_OAuthClientId
from .edr_crowd_strike import EdrCrowdStrike
from .edr_defender import EdrDefender
from .edr_malwarebytes import EdrMalwarebytes
from .edr_sentinel_one import EdrSentinelOne
from .edr_sophos import EdrSophos
from .edr_tanium import EdrTanium
from .elasticsearch_auth_options import ElasticsearchAuthOptions
from .elasticsearch_credential import (
    ElasticsearchCredential,
    ElasticsearchCredential_Basic,
    ElasticsearchCredential_BasicId,
    ElasticsearchCredential_OAuthClient,
    ElasticsearchCredential_OAuthClientId,
    ElasticsearchCredential_Token,
    ElasticsearchCredential_TokenId,
)
from .elasticsearch_shared_secret import (
    ElasticsearchSharedSecret,
    ElasticsearchSharedSecret_Secret,
    ElasticsearchSharedSecret_SecretId,
)
from .entra_id_credential import EntraIdCredential, EntraIdCredential_OAuthClient, EntraIdCredential_OAuthClientId
from .freshdesk_credential import FreshdeskCredential, FreshdeskCredential_Token, FreshdeskCredential_TokenId
from .gcs_credential import GcsCredential, GcsCredential_Aws, GcsCredential_AwsId
from .google_chronicle_credential import (
    GoogleChronicleCredential,
    GoogleChronicleCredential_OAuthClient,
    GoogleChronicleCredential_OAuthClientId,
)
from .google_credential import GoogleCredential, GoogleCredential_OAuthClient, GoogleCredential_OAuthClientId
from .google_service_account_credential import (
    GoogleServiceAccountCredential,
    GoogleServiceAccountCredential_OAuthClient,
    GoogleServiceAccountCredential_OAuthClientId,
)
from .identity_entra_id import IdentityEntraId
from .identity_google import IdentityGoogle
from .identity_okta import IdentityOkta
from .identity_ping_one import IdentityPingOne
from .jira_credential import JiraCredential, JiraCredential_Basic, JiraCredential_BasicId
from .malwarebytes_credential import (
    MalwarebytesCredential,
    MalwarebytesCredential_OAuthClient,
    MalwarebytesCredential_OAuthClientId,
)
from .notifications_jira import NotificationsJira
from .notifications_mock import NotificationsMock
from .notifications_slack import NotificationsSlack
from .notifications_slack_webhook import NotificationsSlackWebhook
from .notifications_teams import NotificationsTeams
from .nozomi_vantage_credential import (
    NozomiVantageCredential,
    NozomiVantageCredential_Basic,
    NozomiVantageCredential_BasicId,
)
from .nucleus_credential import NucleusCredential, NucleusCredential_Token, NucleusCredential_TokenId
from .okta_credential import (
    OktaCredential,
    OktaCredential_OAuthClient,
    OktaCredential_OAuthClientId,
    OktaCredential_Token,
    OktaCredential_TokenId,
)
from .open_search_credential import OpenSearchCredential, OpenSearchCredential_Basic, OpenSearchCredential_BasicId
from .pager_duty_credential import PagerDutyCredential, PagerDutyCredential_Token, PagerDutyCredential_TokenId
from .ping_one_credential import PingOneCredential, PingOneCredential_Token, PingOneCredential_TokenId
from .provider_config import (
    ProviderConfig,
    ProviderConfig_AssetsArmisCentrix,
    ProviderConfig_AssetsArmisCentrixMock,
    ProviderConfig_AssetsAxonius,
    ProviderConfig_AssetsCrowdstrike,
    ProviderConfig_AssetsNozomiVantage,
    ProviderConfig_AssetsNozomiVantageMock,
    ProviderConfig_AssetsQualysCloud,
    ProviderConfig_AssetsQualysCloudMock,
    ProviderConfig_AssetsServicenow,
    ProviderConfig_AssetsServicenowMock,
    ProviderConfig_AssetsSevco,
    ProviderConfig_AssetsTaniumCloud,
    ProviderConfig_AssetsTaniumCloudMock,
    ProviderConfig_CloudsecurityCrowdstrike,
    ProviderConfig_CloudsecurityDefender,
    ProviderConfig_EdrCrowdstrike,
    ProviderConfig_EdrDefender,
    ProviderConfig_EdrMalwarebytes,
    ProviderConfig_EdrSentinelone,
    ProviderConfig_EdrSophos,
    ProviderConfig_EdrTanium,
    ProviderConfig_IdentityEntraId,
    ProviderConfig_IdentityGoogle,
    ProviderConfig_IdentityOkta,
    ProviderConfig_IdentityPingone,
    ProviderConfig_NotificationsJira,
    ProviderConfig_NotificationsMockNotifications,
    ProviderConfig_NotificationsSlack,
    ProviderConfig_NotificationsSlackWebhook,
    ProviderConfig_NotificationsTeams,
    ProviderConfig_SiemCrowdstrike,
    ProviderConfig_SiemElasticsearch,
    ProviderConfig_SiemGoogleChronicle,
    ProviderConfig_SiemGoogleSecurityOperations,
    ProviderConfig_SiemMockSiem,
    ProviderConfig_SiemOpensearch,
    ProviderConfig_SiemQRadar,
    ProviderConfig_SiemRapid7Insightidr,
    ProviderConfig_SiemSentinel,
    ProviderConfig_SiemSplunk,
    ProviderConfig_SiemSumoLogic,
    ProviderConfig_SinkAwsSecurityLake,
    ProviderConfig_SinkAwsSqs,
    ProviderConfig_SinkAzureMonitorLogs,
    ProviderConfig_SinkCrowdstrikeHec,
    ProviderConfig_SinkElasticsearch,
    ProviderConfig_SinkGoogleSecOps,
    ProviderConfig_SinkGoogleSecurityOperations,
    ProviderConfig_SinkMockSink,
    ProviderConfig_SinkOpensearch,
    ProviderConfig_SinkSplunk,
    ProviderConfig_StorageAwsS3,
    ProviderConfig_StorageAzureBlob,
    ProviderConfig_StorageGcs,
    ProviderConfig_StorageMockStorage,
    ProviderConfig_TicketingAutotask,
    ProviderConfig_TicketingFreshdesk,
    ProviderConfig_TicketingJira,
    ProviderConfig_TicketingMockTicketing,
    ProviderConfig_TicketingPagerduty,
    ProviderConfig_TicketingServicenow,
    ProviderConfig_TicketingServicenowSir,
    ProviderConfig_TicketingTorq,
    ProviderConfig_TicketingZendesk,
    ProviderConfig_VulnerabilitiesCrowdstrike,
    ProviderConfig_VulnerabilitiesNucleus,
    ProviderConfig_VulnerabilitiesQualysCloud,
    ProviderConfig_VulnerabilitiesQualysCloudMock,
    ProviderConfig_VulnerabilitiesRapid7InsightCloud,
    ProviderConfig_VulnerabilitiesRapid7InsightCloudMock,
    ProviderConfig_VulnerabilitiesTaniumCloud,
    ProviderConfig_VulnerabilitiesTaniumCloudMock,
    ProviderConfig_VulnerabilitiesTenableCloud,
)
from .provider_config_id import ProviderConfigId
from .q_radar_credential import QRadarCredential, QRadarCredential_Token, QRadarCredential_TokenId
from .qualys_cloud_credential import QualysCloudCredential, QualysCloudCredential_Basic, QualysCloudCredential_BasicId
from .rapid_7_insight_cloud_credential import (
    Rapid7InsightCloudCredential,
    Rapid7InsightCloudCredential_Token,
    Rapid7InsightCloudCredential_TokenId,
)
from .sentinel_credential import SentinelCredential, SentinelCredential_OAuthClient, SentinelCredential_OAuthClientId
from .sentinel_one_credential import SentinelOneCredential, SentinelOneCredential_Token, SentinelOneCredential_TokenId
from .sentinel_one_edr_events_credential import (
    SentinelOneEdrEventsCredential,
    SentinelOneEdrEventsCredential_Token,
    SentinelOneEdrEventsCredential_TokenId,
)
from .service_now_credential import (
    ServiceNowCredential,
    ServiceNowCredential_Basic,
    ServiceNowCredential_BasicId,
    ServiceNowCredential_Token,
    ServiceNowCredential_TokenId,
)
from .sevco_credential import SevcoCredential, SevcoCredential_Token, SevcoCredential_TokenId
from .siem_crowdstrike import SiemCrowdstrike
from .siem_elasticsearch import SiemElasticsearch
from .siem_google_chronicle import SiemGoogleChronicle
from .siem_google_security_operations import SiemGoogleSecurityOperations
from .siem_mock import SiemMock
from .siem_open_search import SiemOpenSearch
from .siem_q_radar import SiemQRadar
from .siem_rapid_7_insight_idr import SiemRapid7InsightIdr
from .siem_sentinel import SiemSentinel
from .siem_splunk import SiemSplunk
from .siem_sumo_logic import SiemSumoLogic
from .sink_aws_security_lake import SinkAwsSecurityLake
from .sink_aws_sqs import SinkAwsSqs
from .sink_azure_monitor_logs import SinkAzureMonitorLogs
from .sink_crowdstrike_hec import SinkCrowdstrikeHec
from .sink_elasticsearch import SinkElasticsearch
from .sink_google_sec_ops import SinkGoogleSecOps
from .sink_google_security_operations import SinkGoogleSecurityOperations
from .sink_mock import SinkMock
from .sink_open_search import SinkOpenSearch
from .sink_splunk import SinkSplunk
from .slack_credential import SlackCredential, SlackCredential_Token, SlackCredential_TokenId
from .slack_webhook_credential import (
    SlackWebhookCredential,
    SlackWebhookCredential_Secret,
    SlackWebhookCredential_SecretId,
)
from .sophos_credential import SophosCredential, SophosCredential_OAuthClient, SophosCredential_OAuthClientId
from .splunk_hec_token import SplunkHecToken, SplunkHecToken_Token, SplunkHecToken_TokenId
from .splunk_search_credential import (
    SplunkSearchCredential,
    SplunkSearchCredential_Token,
    SplunkSearchCredential_TokenId,
)
from .storage_aws_s_3 import StorageAwsS3
from .storage_azure_blob import StorageAzureBlob
from .storage_gcs import StorageGcs
from .storage_mock import StorageMock
from .sumo_logic_collection_url import (
    SumoLogicCollectionUrl,
    SumoLogicCollectionUrl_Secret,
    SumoLogicCollectionUrl_SecretId,
)
from .sumo_logic_credential import SumoLogicCredential, SumoLogicCredential_Basic, SumoLogicCredential_BasicId
from .tanium_cloud_credential import TaniumCloudCredential, TaniumCloudCredential_Token, TaniumCloudCredential_TokenId
from .teams_credential import (
    TeamsCredential,
    TeamsCredential_OAuthClient,
    TeamsCredential_OAuthClientId,
    TeamsCredential_WebhookUrl,
    TeamsCredential_WebhookUrlId,
)
from .tenable_cloud_credential import (
    TenableCloudCredential,
    TenableCloudCredential_Token,
    TenableCloudCredential_TokenId,
)
from .ticketing_autotask import TicketingAutotask
from .ticketing_freshdesk import TicketingFreshdesk
from .ticketing_jira import TicketingJira
from .ticketing_mock import TicketingMock
from .ticketing_pager_duty import TicketingPagerDuty
from .ticketing_service_now import TicketingServiceNow
from .ticketing_service_now_sir import TicketingServiceNowSir
from .ticketing_torq import TicketingTorq
from .ticketing_zendesk import TicketingZendesk
from .torq_credential import TorqCredential, TorqCredential_OAuthClient, TorqCredential_OAuthClientId
from .vulnerabilities_crowd_strike import VulnerabilitiesCrowdStrike
from .vulnerabilities_nucleus import VulnerabilitiesNucleus
from .vulnerabilities_qualys_cloud import VulnerabilitiesQualysCloud
from .vulnerabilities_qualys_cloud_dataset import VulnerabilitiesQualysCloudDataset
from .vulnerabilities_qualys_cloud_mock import VulnerabilitiesQualysCloudMock
from .vulnerabilities_rapid_7_insight_cloud import VulnerabilitiesRapid7InsightCloud
from .vulnerabilities_rapid_7_insight_cloud_dataset import VulnerabilitiesRapid7InsightCloudDataset
from .vulnerabilities_rapid_7_insight_cloud_mock import VulnerabilitiesRapid7InsightCloudMock
from .vulnerabilities_tanium_cloud import VulnerabilitiesTaniumCloud
from .vulnerabilities_tanium_cloud_dataset import VulnerabilitiesTaniumCloudDataset
from .vulnerabilities_tanium_cloud_mock import VulnerabilitiesTaniumCloudMock
from .vulnerabilities_tenable_cloud import VulnerabilitiesTenableCloud
from .zendesk_credential import ZendeskCredential, ZendeskCredential_Basic, ZendeskCredential_BasicId

__all__ = [
    "ArmisCredential",
    "ArmisCredential_Token",
    "ArmisCredential_TokenId",
    "AssetsArmisCentrix",
    "AssetsArmisCentrixMock",
    "AssetsArmisDataset",
    "AssetsAxonius",
    "AssetsCrowdStrike",
    "AssetsNozomiVantage",
    "AssetsNozomiVantageDataset",
    "AssetsNozomiVantageMock",
    "AssetsQualysCloud",
    "AssetsQualysCloudDataset",
    "AssetsQualysCloudMock",
    "AssetsServiceNow",
    "AssetsServiceNowDataset",
    "AssetsServiceNowMock",
    "AssetsSevco",
    "AssetsTaniumCloud",
    "AssetsTaniumCloudDataset",
    "AssetsTaniumCloudMock",
    "AutotaskApiIntegrationCodeCredential",
    "AutotaskApiIntegrationCodeCredential_Secret",
    "AutotaskApiIntegrationCodeCredential_SecretId",
    "AutotaskSecretCredential",
    "AutotaskSecretCredential_Secret",
    "AutotaskSecretCredential_SecretId",
    "AwsS3Credential",
    "AwsS3Credential_Aws",
    "AwsS3Credential_AwsId",
    "AwsSecurityLakeCredential",
    "AwsSecurityLakeCredential_Aws",
    "AwsSecurityLakeCredential_AwsId",
    "AwsSqsCredential",
    "AwsSqsCredential_Aws",
    "AwsSqsCredential_AwsId",
    "AxoniusCredential",
    "AxoniusCredential_Basic",
    "AxoniusCredential_BasicId",
    "AzureBlobCredential",
    "AzureBlobCredential_Token",
    "AzureBlobCredential_TokenId",
    "AzureMonitorLogsCredential",
    "AzureMonitorLogsCredential_Token",
    "AzureMonitorLogsCredential_TokenId",
    "CloudSecurityCrowdStrike",
    "CloudSecurityDefender",
    "CrowdStrikeCredential",
    "CrowdStrikeCredential_OAuthClient",
    "CrowdStrikeCredential_OAuthClientId",
    "CrowdstrikeHecCredential",
    "CrowdstrikeHecCredential_Token",
    "CrowdstrikeHecCredential_TokenId",
    "CustomFieldMapping",
    "DefenderCredential",
    "DefenderCredential_OAuthClient",
    "DefenderCredential_OAuthClientId",
    "EdrCrowdStrike",
    "EdrDefender",
    "EdrMalwarebytes",
    "EdrSentinelOne",
    "EdrSophos",
    "EdrTanium",
    "ElasticsearchAuthOptions",
    "ElasticsearchCredential",
    "ElasticsearchCredential_Basic",
    "ElasticsearchCredential_BasicId",
    "ElasticsearchCredential_OAuthClient",
    "ElasticsearchCredential_OAuthClientId",
    "ElasticsearchCredential_Token",
    "ElasticsearchCredential_TokenId",
    "ElasticsearchSharedSecret",
    "ElasticsearchSharedSecret_Secret",
    "ElasticsearchSharedSecret_SecretId",
    "EntraIdCredential",
    "EntraIdCredential_OAuthClient",
    "EntraIdCredential_OAuthClientId",
    "FreshdeskCredential",
    "FreshdeskCredential_Token",
    "FreshdeskCredential_TokenId",
    "GcsCredential",
    "GcsCredential_Aws",
    "GcsCredential_AwsId",
    "GoogleChronicleCredential",
    "GoogleChronicleCredential_OAuthClient",
    "GoogleChronicleCredential_OAuthClientId",
    "GoogleCredential",
    "GoogleCredential_OAuthClient",
    "GoogleCredential_OAuthClientId",
    "GoogleServiceAccountCredential",
    "GoogleServiceAccountCredential_OAuthClient",
    "GoogleServiceAccountCredential_OAuthClientId",
    "IdentityEntraId",
    "IdentityGoogle",
    "IdentityOkta",
    "IdentityPingOne",
    "JiraCredential",
    "JiraCredential_Basic",
    "JiraCredential_BasicId",
    "MalwarebytesCredential",
    "MalwarebytesCredential_OAuthClient",
    "MalwarebytesCredential_OAuthClientId",
    "NotificationsJira",
    "NotificationsMock",
    "NotificationsSlack",
    "NotificationsSlackWebhook",
    "NotificationsTeams",
    "NozomiVantageCredential",
    "NozomiVantageCredential_Basic",
    "NozomiVantageCredential_BasicId",
    "NucleusCredential",
    "NucleusCredential_Token",
    "NucleusCredential_TokenId",
    "OktaCredential",
    "OktaCredential_OAuthClient",
    "OktaCredential_OAuthClientId",
    "OktaCredential_Token",
    "OktaCredential_TokenId",
    "OpenSearchCredential",
    "OpenSearchCredential_Basic",
    "OpenSearchCredential_BasicId",
    "PagerDutyCredential",
    "PagerDutyCredential_Token",
    "PagerDutyCredential_TokenId",
    "PingOneCredential",
    "PingOneCredential_Token",
    "PingOneCredential_TokenId",
    "ProviderConfig",
    "ProviderConfigId",
    "ProviderConfig_AssetsArmisCentrix",
    "ProviderConfig_AssetsArmisCentrixMock",
    "ProviderConfig_AssetsAxonius",
    "ProviderConfig_AssetsCrowdstrike",
    "ProviderConfig_AssetsNozomiVantage",
    "ProviderConfig_AssetsNozomiVantageMock",
    "ProviderConfig_AssetsQualysCloud",
    "ProviderConfig_AssetsQualysCloudMock",
    "ProviderConfig_AssetsServicenow",
    "ProviderConfig_AssetsServicenowMock",
    "ProviderConfig_AssetsSevco",
    "ProviderConfig_AssetsTaniumCloud",
    "ProviderConfig_AssetsTaniumCloudMock",
    "ProviderConfig_CloudsecurityCrowdstrike",
    "ProviderConfig_CloudsecurityDefender",
    "ProviderConfig_EdrCrowdstrike",
    "ProviderConfig_EdrDefender",
    "ProviderConfig_EdrMalwarebytes",
    "ProviderConfig_EdrSentinelone",
    "ProviderConfig_EdrSophos",
    "ProviderConfig_EdrTanium",
    "ProviderConfig_IdentityEntraId",
    "ProviderConfig_IdentityGoogle",
    "ProviderConfig_IdentityOkta",
    "ProviderConfig_IdentityPingone",
    "ProviderConfig_NotificationsJira",
    "ProviderConfig_NotificationsMockNotifications",
    "ProviderConfig_NotificationsSlack",
    "ProviderConfig_NotificationsSlackWebhook",
    "ProviderConfig_NotificationsTeams",
    "ProviderConfig_SiemCrowdstrike",
    "ProviderConfig_SiemElasticsearch",
    "ProviderConfig_SiemGoogleChronicle",
    "ProviderConfig_SiemGoogleSecurityOperations",
    "ProviderConfig_SiemMockSiem",
    "ProviderConfig_SiemOpensearch",
    "ProviderConfig_SiemQRadar",
    "ProviderConfig_SiemRapid7Insightidr",
    "ProviderConfig_SiemSentinel",
    "ProviderConfig_SiemSplunk",
    "ProviderConfig_SiemSumoLogic",
    "ProviderConfig_SinkAwsSecurityLake",
    "ProviderConfig_SinkAwsSqs",
    "ProviderConfig_SinkAzureMonitorLogs",
    "ProviderConfig_SinkCrowdstrikeHec",
    "ProviderConfig_SinkElasticsearch",
    "ProviderConfig_SinkGoogleSecOps",
    "ProviderConfig_SinkGoogleSecurityOperations",
    "ProviderConfig_SinkMockSink",
    "ProviderConfig_SinkOpensearch",
    "ProviderConfig_SinkSplunk",
    "ProviderConfig_StorageAwsS3",
    "ProviderConfig_StorageAzureBlob",
    "ProviderConfig_StorageGcs",
    "ProviderConfig_StorageMockStorage",
    "ProviderConfig_TicketingAutotask",
    "ProviderConfig_TicketingFreshdesk",
    "ProviderConfig_TicketingJira",
    "ProviderConfig_TicketingMockTicketing",
    "ProviderConfig_TicketingPagerduty",
    "ProviderConfig_TicketingServicenow",
    "ProviderConfig_TicketingServicenowSir",
    "ProviderConfig_TicketingTorq",
    "ProviderConfig_TicketingZendesk",
    "ProviderConfig_VulnerabilitiesCrowdstrike",
    "ProviderConfig_VulnerabilitiesNucleus",
    "ProviderConfig_VulnerabilitiesQualysCloud",
    "ProviderConfig_VulnerabilitiesQualysCloudMock",
    "ProviderConfig_VulnerabilitiesRapid7InsightCloud",
    "ProviderConfig_VulnerabilitiesRapid7InsightCloudMock",
    "ProviderConfig_VulnerabilitiesTaniumCloud",
    "ProviderConfig_VulnerabilitiesTaniumCloudMock",
    "ProviderConfig_VulnerabilitiesTenableCloud",
    "QRadarCredential",
    "QRadarCredential_Token",
    "QRadarCredential_TokenId",
    "QualysCloudCredential",
    "QualysCloudCredential_Basic",
    "QualysCloudCredential_BasicId",
    "Rapid7InsightCloudCredential",
    "Rapid7InsightCloudCredential_Token",
    "Rapid7InsightCloudCredential_TokenId",
    "SentinelCredential",
    "SentinelCredential_OAuthClient",
    "SentinelCredential_OAuthClientId",
    "SentinelOneCredential",
    "SentinelOneCredential_Token",
    "SentinelOneCredential_TokenId",
    "SentinelOneEdrEventsCredential",
    "SentinelOneEdrEventsCredential_Token",
    "SentinelOneEdrEventsCredential_TokenId",
    "ServiceNowCredential",
    "ServiceNowCredential_Basic",
    "ServiceNowCredential_BasicId",
    "ServiceNowCredential_Token",
    "ServiceNowCredential_TokenId",
    "SevcoCredential",
    "SevcoCredential_Token",
    "SevcoCredential_TokenId",
    "SiemCrowdstrike",
    "SiemElasticsearch",
    "SiemGoogleChronicle",
    "SiemGoogleSecurityOperations",
    "SiemMock",
    "SiemOpenSearch",
    "SiemQRadar",
    "SiemRapid7InsightIdr",
    "SiemSentinel",
    "SiemSplunk",
    "SiemSumoLogic",
    "SinkAwsSecurityLake",
    "SinkAwsSqs",
    "SinkAzureMonitorLogs",
    "SinkCrowdstrikeHec",
    "SinkElasticsearch",
    "SinkGoogleSecOps",
    "SinkGoogleSecurityOperations",
    "SinkMock",
    "SinkOpenSearch",
    "SinkSplunk",
    "SlackCredential",
    "SlackCredential_Token",
    "SlackCredential_TokenId",
    "SlackWebhookCredential",
    "SlackWebhookCredential_Secret",
    "SlackWebhookCredential_SecretId",
    "SophosCredential",
    "SophosCredential_OAuthClient",
    "SophosCredential_OAuthClientId",
    "SplunkHecToken",
    "SplunkHecToken_Token",
    "SplunkHecToken_TokenId",
    "SplunkSearchCredential",
    "SplunkSearchCredential_Token",
    "SplunkSearchCredential_TokenId",
    "StorageAwsS3",
    "StorageAzureBlob",
    "StorageGcs",
    "StorageMock",
    "SumoLogicCollectionUrl",
    "SumoLogicCollectionUrl_Secret",
    "SumoLogicCollectionUrl_SecretId",
    "SumoLogicCredential",
    "SumoLogicCredential_Basic",
    "SumoLogicCredential_BasicId",
    "TaniumCloudCredential",
    "TaniumCloudCredential_Token",
    "TaniumCloudCredential_TokenId",
    "TeamsCredential",
    "TeamsCredential_OAuthClient",
    "TeamsCredential_OAuthClientId",
    "TeamsCredential_WebhookUrl",
    "TeamsCredential_WebhookUrlId",
    "TenableCloudCredential",
    "TenableCloudCredential_Token",
    "TenableCloudCredential_TokenId",
    "TicketingAutotask",
    "TicketingFreshdesk",
    "TicketingJira",
    "TicketingMock",
    "TicketingPagerDuty",
    "TicketingServiceNow",
    "TicketingServiceNowSir",
    "TicketingTorq",
    "TicketingZendesk",
    "TorqCredential",
    "TorqCredential_OAuthClient",
    "TorqCredential_OAuthClientId",
    "VulnerabilitiesCrowdStrike",
    "VulnerabilitiesNucleus",
    "VulnerabilitiesQualysCloud",
    "VulnerabilitiesQualysCloudDataset",
    "VulnerabilitiesQualysCloudMock",
    "VulnerabilitiesRapid7InsightCloud",
    "VulnerabilitiesRapid7InsightCloudDataset",
    "VulnerabilitiesRapid7InsightCloudMock",
    "VulnerabilitiesTaniumCloud",
    "VulnerabilitiesTaniumCloudDataset",
    "VulnerabilitiesTaniumCloudMock",
    "VulnerabilitiesTenableCloud",
    "ZendeskCredential",
    "ZendeskCredential_Basic",
    "ZendeskCredential_BasicId",
]
