# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class CreateAssetStatus(str, enum.Enum):
    UNKNOWN = "Unknown"
    PENDING = "Pending"
    COMPLETE = "Complete"

    def visit(
        self,
        unknown: typing.Callable[[], T_Result],
        pending: typing.Callable[[], T_Result],
        complete: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is CreateAssetStatus.UNKNOWN:
            return unknown()
        if self is CreateAssetStatus.PENDING:
            return pending()
        if self is CreateAssetStatus.COMPLETE:
            return complete()
