# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AssetsServiceNowDataset(str, enum.Enum):
    BASIC_VER_0 = "basic_v0"

    def visit(self, basic_ver_0: typing.Callable[[], T_Result]) -> T_Result:
        if self is AssetsServiceNowDataset.BASIC_VER_0:
            return basic_ver_0()
