# This file was auto-generated by Fern from our API Definition.

from .....v_1_4_0.resources.cloudresourcesinventoryinfo.resources.classes.types.cloud_resources_inventory_info import (
    CloudResourcesInventoryInfo as resources_ocsf_resources_v_1_4_0_resources_cloudresourcesinventoryinfo_resources_classes_types_cloud_resources_inventory_info_CloudResourcesInventoryInfo,
)

CloudResourcesInventoryInfo = resources_ocsf_resources_v_1_4_0_resources_cloudresourcesinventoryinfo_resources_classes_types_cloud_resources_inventory_info_CloudResourcesInventoryInfo
