# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.apiactivity.resources.classes.types.api_activity import (
    ApiActivity as resources_ocsf_resources_v_1_3_0_resources_apiactivity_resources_classes_types_api_activity_ApiActivity,
)

ApiActivity = resources_ocsf_resources_v_1_3_0_resources_apiactivity_resources_classes_types_api_activity_ApiActivity
